<template>
    <div>
        <el-upload
            class="upload-demo"
            :action="upload"
            list-type="picture-card"
            :auto-upload="true"
            :multiple="true"
            :headers="headers"
            :file-list="fileList"
            :on-success="success"
            :on-error="error"
            :data="updata"
            :accept="accept"
            :disabled="disabled"
            :before-upload="uploadBeforeFile"
            :on-progress="onProgress"
            v-loading.fullscreen="loading"
        >
            <i slot="default" class="el-icon-plus"></i>
            <div
                slot="file"
                slot-scope="{file}"
                style="width: 100%; height: 100%"
            >
                <!-- {{file}} -->
                <img
                    class="el-upload-list__item-thumbnail"
                    :src="file.url"
                    alt=""
                />

                <span class="el-upload-list__item-actions">
                    <span
                        class="el-upload-list__item-preview"
                        @click="handlePictureCardPreview(file)"
                    >
                        <i class="el-icon-zoom-in"></i>
                    </span>
                    <span
                        v-if="!disabled"
                        class="el-upload-list__item-delete"
                        @click="handleDownload(file)"
                    >
                        <i class="el-icon-download"></i>
                    </span>
                    <span
                        v-if="!disabled"
                        class="el-upload-list__item-delete"
                        @click="handleRemove(file)"
                    >
                        <i class="el-icon-delete"></i>
                    </span>
                </span>
            </div>
        </el-upload>

        <el-dialog
            append-to-body
            :visible.sync="updialogVisible"
            :close-on-click-modal="false"
            :close-on-press-escape="false"
            title="附件预览"
        >
            <img width="100%" :src="dialogImageUrl" alt="" />
        </el-dialog>
    </div>
</template>

<script>
import {mapState} from 'vuex'
import basicData from '@/api/basicData.js'
import req from '@/request.js'
export default {
    props: {
        accept: {
            type: String,
        },
        disabled: {
            type: Boolean,
        },
        dadToSon: {
            type: Object,
        },
    },
    data() {
        return {
            updata: {
                bizPath: this.dadToSon.bizPath,
            },
            dialogImageUrl: '',
            updialogVisible: false,
            fileList: this.dadToSon.fileList,
            imgUrl: this.url,
            loading: false,
            // disabled: false, //按钮禁用控制
        }
    },
    watch: {
        dadToSon(newVal) {
            this.fileList = newVal.fileList
        },
    },
    created() {},
    computed: mapState({
        deleteUrl: function () {
            return (
                window.context.yhxt +
                '/bizMigrantBuildersInformation/v1/updateMigrantWorkersInformation'
            )
        },
        headers: (state) => {
            return {Authorization: `Bearer ${state.login.currentUser.token}`}
        },
        upload: function () {
            return window.context.portal + '/accessory/manager/v1/minioUpload'
        },
    }),
    methods: {
        uploadBeforeFile(file) {
            this.loading = true
        },
        onProgress(event, file, fileList) {
            console.log(fileList, 'dddddddd')
        },
        error() {
            this.loading = false
        },
        success(response, file, fileList) {
            console.log(file, fileList)
            this.loading = false
            // console.log(response, file, fileList, 'ddddddddd')
            this.$message({
                type: response ? 'success' : 'warning',
                message: response ? '上传成功' : '上传失败',
            })
            let imgList = []
            fileList.forEach((item) => {
                if (!item.id) {
                    if (item.response) {
                        imgList.push({
                            name: item.name,
                            size: item.size,
                            url: item.response,
                            type: item.raw.type,
                            uid: item.uid,
                        })
                    }
                } else {
                    imgList.push(item)
                }
            })
            this.fileList = fileList
            this.$emit('sonToDad', imgList)
        },
        //删除事件
        handleRemove(file) {
            let INdex = this.fileList.findIndex((item) => {
                return item.uid == file.uid
            })
            this.fileList.splice(INdex, 1)
            let imgList = []
            this.fileList.forEach((item) => {
                if (!item.id) {
                    if (item.response) {
                        imgList.push({
                            name: item.name,
                            size: item.size,
                            url: item.response,
                            type: item.raw.type,
                            uid: item.uid,
                        })
                    }
                } else {
                    imgList.push(item)
                }
            })
            this.$emit('sonToDad', imgList)
            if (file.id) {
                basicData.deleteEnclosureManagement(file.id).then((res) => {})
            }
        },
        handlePictureCardPreview(file) {
            this.dialogImageUrl = file.url
            this.updialogVisible = true
        },
        handleDownload(file) {
            // console.log(file)
            if (file.id) {
                window.open(file.url)
            } else {
                this.$message.info('请先保存附件')
            }
            // this.$emit('downFile',file)
        },
    },
}
</script>

<style lang="scss" scoped>
.upload-demo {
  // max-width: 570px;
  // margin-top: 5px;
}
</style>
